Onespacemedia CMS
=================

.. image:: https://img.shields.io/badge/license-New%20BSD-blue.svg
    :target: https://raw.githubusercontent.com/onespacemedia/cms/master/LICENSE

.. image:: https://travis-ci.org/onespacemedia/cms.svg?branch=master
    :target: https://travis-ci.org/onespacemedia/cms

.. image:: https://coveralls.io/repos/onespacemedia/cms/badge.svg?branch=master
    :target: https://coveralls.io/r/onespacemedia/cms?branch=master


A collection of Django extensions that add content-management facilities
to Django projects, originally forked from
`etianen/cms <https://github.com/etianen/cms>`__. The team at
`Onespacemedia <http://www.onespacemedia.com>`__ are actively working on
the project, adding new features, updating existing ones and keeping it
working with the latest versions of Django.

The current version of ``onespacemedia-cms`` should always be compatible
with the current version of Django.

Resources
=========

* `Documentation <http://onespacemedia-cms.readthedocs.org/>`_
* `Code <http://github.com/onespacemedia/cms>`_
* `Travis CI <http://travis-ci.org/onespacemedia/cms>`_
* `Coveralls <https://coveralls.io/r/onespacemedia/cms>`_
